from os.path import dirname, join


DIR_RES = join(dirname(__file__), "res")
FILE_SETTING = "glm_setting.py"
